@@ -1,3 +1,4 @@
+var lastEv;
 function detectDoubleTapClosure() {
   let lastTap = 0;
   let timeout;
@@ -5,7 +6,8 @@ function detectDoubleTapClosure() {
     const curTime = new Date().getTime();
     const tapLen = curTime - lastTap;
     if (tapLen < 500 && tapLen > 0) {
-      addAnnotation(event)
+      lastEv=event;
+      showPopup();
       event.preventDefault();
     } else {
       timeout = setTimeout(() => {
@@ -15,25 +17,9 @@ function detectDoubleTapClosure() {
     lastTap = curTime;
   };
 }
-
-
-function selectText(nodeId) {
-  const node = document.getElementById(nodeId);
-  node.focus();
-  if (document.body.createTextRange) {
-      const range = document.body.createTextRange();
-      range.moveToElementText(node);
-      range.select();
-      node.focus();
-  } else if (window.getSelection) {
-      const selection = window.getSelection();
-      const range = document.createRange();
-      range.selectNodeContents(node);
-      selection.removeAllRanges();
-      selection.addRange(range);
-  } else {
-      console.warn("Could not select text in node: Unsupported browser.");
-  }
+function showPopup(){
+  var popup = document.getElementById("myPopup");
+  popup.classList.toggle("show");
 }
 function mobileCheck () {
   let check = false;
@@ -41,9 +27,15 @@ function mobileCheck () {
   return check;
 }
 function sendValue(value) {
-  Streamlit.setComponentValue(value)
+  var dp=value.getAttribute("data-position");
+  Streamlit.setComponentValue(dp)
 }
-function addAnnotation(event){
+function annotate(){
+  var nm = document.getElementById("nm");
+  addAnnotation(lastEv,nm.value)
+  showPopup();
+}
+function addAnnotation(event,name){
   const modelViewer = document.querySelector("#mod");
   var x=event.clientX;
   var y=event.clientY;
@@ -53,12 +45,11 @@ function addAnnotation(event){
   }
   let hit = modelViewer.positionAndNormalFromPoint(x, y);
   var node=`
-    <button onclick="sendValue('${hit.position.x}')" slot="hotspot-hand${hit.position.x}" data-position="${hit.position.x} ${hit.position.y} ${hit.position.z}" data-normal="${hit.normal.x} ${hit.normal.y} ${hit.normal.z}">
-      <div onfocus="selectText('ano${hit.position.x}')" id="ano${hit.position.x}" class="up annotation" contenteditable="true">Edit text</div>
+    <button class="bta" onclick="sendValue(this)" slot="hotspot-hand${hit.position.x}" data-position="${hit.position.x} ${hit.position.y} ${hit.position.z}" data-normal="${hit.normal.x} ${hit.normal.y} ${hit.normal.z}">
+      <div id="ano${hit.position.x}" class="up annotation">${name}</div>
     </button>`
   modelViewer.insertAdjacentHTML( 'beforeend', node );
-  selectText(`ano${hit.position.x}`)
-  sendValue(`${hit.position.x} ${hit.position.y} ${hit.position.z} ${hit.normal.x} ${hit.normal.y} ${hit.normal.z}`)
+  // sendValue(`${hit.position.x} ${hit.position.y} ${hit.position.z} ${hit.normal.x} ${hit.normal.y} ${hit.normal.z}`)
 }
 function onRender(event) {
   const {model,key,} = event.detail.args;
@@ -68,7 +59,8 @@ function onRender(event) {
     }
     const modelViewer = document.querySelector("#mod");
     modelViewer.addEventListener('dblclick', (event) => {
-      addAnnotation(event)
+      lastEv=event;
+      showPopup();
     }, true);
     document.getElementById("mod").setAttribute("src",model);
     window.rendered = true
@@ -76,13 +68,18 @@ function onRender(event) {
   
 }
 
-// Render the component whenever python send a "render event"
+
 Streamlit.events.addEventListener(Streamlit.RENDER_EVENT, onRender)
-// Tell Streamlit that the component is ready to receive events
+
 Streamlit.setComponentReady()
-// Render with the correct height, if this is a fixed-height component
+
 if(mobileCheck())
   Streamlit.setFrameHeight(400)
 else{
   Streamlit.setFrameHeight(1000)
 }  
+
+//TODO
+// SEND ALL VALUES (pos and text)
+// SEND ACTION (Delete,Create,Click)
+// LOAD POINTS AT LOADING
\ No newline at end of file
